@@ -1,10 +1,12 @@
 package Measure::Everything::Adapter;
+
+# ABSTRACT: Tell Measure::Everything where to send the stats
+our $VERSION = '1.003'; # VERSION
+
 use strict;
 use warnings;
 use Module::Runtime qw(use_module);
 
-# ABSTRACT: Tell Measure::Everything where to send the stats
-
 sub set {
     my ($self, $adapter, @args) = @_;
 
@@ -32,7 +34,7 @@ Measure::Everything::Adapter - Tell Measure::Everything where to send the stats
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -48,11 +50,11 @@ version 1.002
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
