@@ -1,8 +1,10 @@
 package Measure::Everything::Adapter::Base;
-use strict;
-use warnings;
 
 # ABSTRACT: Base class for adapters
+our $VERSION = '1.003'; # VERSION
+
+use strict;
+use warnings;
 
 sub new {
     my $class = shift;
@@ -33,7 +35,7 @@ Measure::Everything::Adapter::Base - Base class for adapters
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 DESCRIPTION
 
@@ -41,11 +43,11 @@ Base class for all Adapters. You won't need this unless you want to write an Ada
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
