@@ -1,11 +1,13 @@
 package Measure::Everything::Adapter::Null;
+
+# ABSTRACT: Null Adapter: ignore all stats
+our $VERSION = '1.003'; # VERSION
+
 use strict;
 use warnings;
 
 use base qw(Measure::Everything::Adapter::Base);
 
-# ABSTRACT: Null Adapter: ignore all stats
-
 sub write { }
 
 1;
@@ -22,7 +24,7 @@ Measure::Everything::Adapter::Null - Null Adapter: ignore all stats
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -34,11 +36,11 @@ Ignore all stats. This Adapter is used if you do not specify an Adapter.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
